==> kmymoney_5.1.1.orig.tar.xz: kmymoney-5.1.1/kmymoney/plugins/weboob/weboob.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "romain@weboob.org",
                "Name": "Romain Bignon",
                "Name[ca@valencia]": "Romain Bignon",
                "Name[ca]": "Romain Bignon",
                "Name[cs]": "Romain Bignon",
                "Name[de]": "Romain Bignon",
                "Name[en_GB]": "Romain Bignon",
                "Name[es]": "Romain Bignon",
                "Name[et]": "Romain Bignon",
                "Name[eu]": "Romain Bignon",
                "Name[fi]": "Romain Bignon",
                "Name[fr]": "Romain Bignon",
                "Name[gl]": "Romain Bignon",
                "Name[ia]": "Romain Bignon",
                "Name[it]": "Romain Bignon",
                "Name[ko]": "Romain Bignon",
                "Name[nl]": "Romain Bignon",
                "Name[pl]": "Romain Bignon",
                "Name[pt]": "Romain Bignon",
                "Name[pt_BR]": "Romain Bignon",
                "Name[ru]": "Romain Bignon",
                "Name[sk]": "Romain Bignon",
                "Name[sv]": "Romain Bignon",
                "Name[uk]": "Romain Bignon",
                "Name[x-test]": "xxRomain Bignonxx"
            }
        ],
        "Description": "Plugin for weboob",
        "Description[ca@valencia]": "Connector per al Weboob",
        "Description[ca]": "Connector per al Weboob",
        "Description[de]": "Modul für Weboob",
        "Description[en_GB]": "Plugin for weboob",
        "Description[es]": "Complemento para weboob",
        "Description[et]": "Weboobi plugin",
        "Description[eu]": "weboob plugina",
        "Description[fi]": "Weboob-liitännäinen",
        "Description[fr]": "Module externe pour weboob",
        "Description[gl]": "Complemento para weboob",
        "Description[it]": "Estensione per weboob",
        "Description[ko]": "Weboob용 플러그인",
        "Description[nl]": "Plug-in voor weboob",
        "Description[pl]": "Wtyczka dla weboob",
        "Description[pt]": "'Plugin' do Weboob",
        "Description[pt_BR]": "Plugin para weboob",
        "Description[sk]": "Plugin pre weboob",
        "Description[sv]": "Insticksprogram för weboob",
        "Description[uk]": "Додаток weboob",
        "Description[x-test]": "xxPlugin for weboobxx",
        "EnabledByDefault": true,
        "Icon": "network-connect",
        "Id": "weboob",
        "License": "GPL",
        "Name": "Weboob",
        "Name[ca@valencia]": "Weboob",
        "Name[ca]": "Weboob",
        "Name[cs]": "Weboob",
        "Name[de]": "Weboob",
        "Name[en_GB]": "Weboob",
        "Name[es]": "Weboob",
        "Name[et]": "Weboob",
        "Name[eu]": "Weboob",
        "Name[fi]": "Weboob",
        "Name[fr]": "Weboob",
        "Name[gl]": "Weboob",
        "Name[it]": "Weboob",
        "Name[ko]": "Weboob",
        "Name[nl]": "Weboob",
        "Name[pl]": "Weboob",
        "Name[pt]": "Weboob",
        "Name[pt_BR]": "Weboob",
        "Name[sk]": "Weboob",
        "Name[sv]": "Weboob",
        "Name[uk]": "Weboob",
        "Name[x-test]": "xxWeboobxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney_5.1.2.orig.tar.xz: kmymoney-5.1.2/kmymoney/plugins/weboob/weboob.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "romain@weboob.org",
                "Name": "Romain Bignon",
                "Name[ca@valencia]": "Romain Bignon",
                "Name[ca]": "Romain Bignon",
                "Name[cs]": "Romain Bignon",
                "Name[de]": "Romain Bignon",
                "Name[en_GB]": "Romain Bignon",
                "Name[es]": "Romain Bignon",
                "Name[et]": "Romain Bignon",
                "Name[eu]": "Romain Bignon",
                "Name[fi]": "Romain Bignon",
                "Name[fr]": "Romain Bignon",
                "Name[gl]": "Romain Bignon",
                "Name[ia]": "Romain Bignon",
                "Name[it]": "Romain Bignon",
                "Name[ko]": "Romain Bignon",
                "Name[nl]": "Romain Bignon",
                "Name[pl]": "Romain Bignon",
                "Name[pt]": "Romain Bignon",
                "Name[pt_BR]": "Romain Bignon",
                "Name[ru]": "Romain Bignon",
                "Name[sk]": "Romain Bignon",
                "Name[sl]": "Romain Bignon",
                "Name[sv]": "Romain Bignon",
                "Name[uk]": "Romain Bignon",
                "Name[x-test]": "xxRomain Bignonxx",
                "Name[zh_CN]": "Romain Bignon"
            }
        ],
        "Description": "Plugin for weboob",
        "Description[ca@valencia]": "Connector per al Weboob",
        "Description[ca]": "Connector per al Weboob",
        "Description[de]": "Modul für Weboob",
        "Description[en_GB]": "Plugin for weboob",
        "Description[es]": "Complemento para weboob",
        "Description[et]": "Weboobi plugin",
        "Description[eu]": "weboob plugina",
        "Description[fi]": "Weboob-liitännäinen",
        "Description[fr]": "Module externe pour weboob",
        "Description[gl]": "Complemento para weboob",
        "Description[it]": "Estensione per weboob",
        "Description[ko]": "Weboob용 플러그인",
        "Description[nl]": "Plug-in voor weboob",
        "Description[pl]": "Wtyczka dla weboob",
        "Description[pt]": "'Plugin' do Weboob",
        "Description[pt_BR]": "Plugin para weboob",
        "Description[sk]": "Plugin pre weboob",
        "Description[sl]": "Vtičnik za weboob",
        "Description[sv]": "Insticksprogram för weboob",
        "Description[uk]": "Додаток weboob",
        "Description[x-test]": "xxPlugin for weboobxx",
        "Description[zh_CN]": "weboob 插件",
        "EnabledByDefault": true,
        "Icon": "network-connect",
        "Id": "weboob",
        "License": "GPL",
        "Name": "Weboob",
        "Name[ca@valencia]": "Weboob",
        "Name[ca]": "Weboob",
        "Name[cs]": "Weboob",
        "Name[de]": "Weboob",
        "Name[en_GB]": "Weboob",
        "Name[es]": "Weboob",
        "Name[et]": "Weboob",
        "Name[eu]": "Weboob",
        "Name[fi]": "Weboob",
        "Name[fr]": "Weboob",
        "Name[gl]": "Weboob",
        "Name[it]": "Weboob",
        "Name[ko]": "Weboob",
        "Name[nl]": "Weboob",
        "Name[pl]": "Weboob",
        "Name[pt]": "Weboob",
        "Name[pt_BR]": "Weboob",
        "Name[sk]": "Weboob",
        "Name[sl]": "Weboob",
        "Name[sv]": "Weboob",
        "Name[uk]": "Weboob",
        "Name[x-test]": "xxWeboobxx",
        "Name[zh_CN]": "Weboob",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
